@@ -51,7 +51,7 @@ def get_trans_dict(trans_from_labels,trans_to_labels,subsample_size='none',prese
             trans_dict[reverse_tdf[k]] = reverse_tdt[v]
         else:
             trans_dict[reverse_tdf[k]] = reverse_tdf[v]
-    if not len(trans_dict) + len(leftovers) == num_from_labs + 1: set_trace()
+    if not len(trans_dict) + len(leftovers) == max(num_from_labs,num_to_labs) + 1: set_trace()
 
     return trans_dict,leftovers
 
